#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_HALF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_HALF_HPP_INCLUDED

#include <boost/simd/constant/include/constants/half.hpp>

#endif
